Dog, Cat & Other Pet Friendly Hotels at Petswelcome.com
Description: Listing of pet friendly hotels, motels, inns, and bed and breakfast's throughout the USA and Canada, all of which accept pets and not just Dogs & Cats but also Birds & exotic animals

Enter City:
Advanced Search
Login to PetsWelcome Passport

## Search By Route and find hotels along the way

Journey Starts From: Add Stops Along the Way (optional)

Journey Ends At:

Search within
miles of route, every
miles along the way.

NEW! Now you can add STOPS ALONG THE WAY and SAVE and edit YOUR ROUTE for future use.

Just create your route and you'll see the option to save it right below the map.

Click here to find out more...

© 2014 petswelcome.com, Inc. Conditions of Use. Please read before using this site.

## My Petswelcome Passport

Now you can save your route and access it anytime on your trip and/or for future travel. If you already have a Petswelcome Passport account, just log-in to save this route.

#### Log-in to your account

#### Create an Account

## Petswelcome Passport

### Get yours today!

Once you put in your Search by Route departure point and destination and click on Get Directions, you will be asked if you'd like to save your route. If you would like to save it, you'll be asked to create you own account by putting in your email address and creating a password so you can access your directions anytime on your trip or in the future.

## Petswelcome Passport

### Get yours today!

To save your route just fill in the information below and you'll be able to keep it as long as you'd like and access it anytime on-line. No more printing and forgetting to take the directions with you. And by saving trees and ink, you'll feel good about yourself, save money, contribute to a cleaner environment and, most importantly, be able to spend more time on having a great trip with your WHOLE family. How sweet is that?

Just fill in the information below to create an Petswelcome Passport account:

Enter your email: Enter your password: Verify your password:

## My Petswelcome Passport

Log-in to your account.

Enter your email address:
Enter your password:
Create Account Lost Password? Learn More…

## Petswelcome Passport

Enter your email address:
Enter your password:
Create Account Lost Password? Learn More…

## Petswelcome Passport

### Reset Password

Enter the email address you used to create your account and we'll send you a link to reset your password: